summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/util/SocketServer.scala
diff options
context:
space:
mode:
authormichelou <michelou@epfl.ch>2006-09-26 14:16:35 +0000
committermichelou <michelou@epfl.ch>2006-09-26 14:16:35 +0000
commit40396d951e31745af414748b1508012f823f2343 (patch)
tree896000986c37b51e533726ec28e56fce0ac79aa2 /src/compiler/scala/tools/util/SocketServer.scala
parent20aa9911d0ee9ed96b2f12642e8e8505782cbc0b (diff)
downloadscala-40396d951e31745af414748b1508012f823f2343.tar.gz
scala-40396d951e31745af414748b1508012f823f2343.tar.bz2
scala-40396d951e31745af414748b1508012f823f2343.zip
removed leading/trailing tabs/blanks in nsc/uti...
removed leading/trailing tabs/blanks in nsc/util/*.scala
Diffstat (limited to 'src/compiler/scala/tools/util/SocketServer.scala')
-rw-r--r--src/compiler/scala/tools/util/SocketServer.scala14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/compiler/scala/tools/util/SocketServer.scala b/src/compiler/scala/tools/util/SocketServer.scala
index e64f55f667..93dbde2694 100644
--- a/src/compiler/scala/tools/util/SocketServer.scala
+++ b/src/compiler/scala/tools/util/SocketServer.scala
@@ -10,13 +10,13 @@
package scala.tools.util
-import java.net._
import java.io._
+import java.net.ServerSocket
-/** This abstract class implements the server communication for
- * the fast Scala compiler.
+/** The abstract class <code>SocketServer</code> implements the server
+ * communication for the fast Scala compiler.
*
- * @author Martin Odersky
+ * @author Martin Odersky
* @version 1.0
*/
abstract class SocketServer {
@@ -42,7 +42,7 @@ abstract class SocketServer {
fatal("Could not listen on any port; exiting.")
}
- def run(): unit = {
+ def run(): unit =
while (!shutDown) {
val serverSocket = try {
new ServerSocket(port)
@@ -61,7 +61,7 @@ abstract class SocketServer {
in = new BufferedReader(new InputStreamReader(clientSocket.getInputStream()))
val bufout = new BufferedOutputStream(clientSocket.getOutputStream, 10240)
- Console.withOut(bufout) {
+ scala.Console.withOut(bufout) {
session()
}
@@ -71,6 +71,6 @@ abstract class SocketServer {
clientSocket.close()
serverSocket.close()
}
- }
+
}